# mlflow-duckdb

[![CI/CD Pipeline](https://github.com/hugodscarvalho/mlflow-duckdb/actions/workflows/ci-cd.yml/badge.svg)](https://github.com/hugodscarvalho/mlflow-duckdb/actions/workflows/ci.yml)
[![Coverage](https://codecov.io/gh/hugodscarvalho/mlflow-duckdb/branch/main/graph/badge.svg)](https://codecov.io/gh/hugodscarvalho/mlflow-duckdb)
[![PyPI version](https://img.shields.io/pypi/v/mlflow-duckdb.svg)](https://pypi.org/project/mlflow-duckdb/)
[![Python versions](https://img.shields.io/pypi/pyversions/mlflow-duckdb.svg)](https://pypi.org/project/mlflow-duckdb/)
[![License](https://img.shields.io/github/license/hugodscarvalho/mlflow-duckdb.svg)](LICENSE)

**An MLflow plugin that enables logging and loading of artifacts and models using DuckDB as a lightweight, serverless backend for portable experiment tracking.**

## Overview

This is the initial release of `mlflow-duckdb`, published to reserve the package name on PyPI and lay the groundwork for future development.

The goal of this plugin is to integrate DuckDB with MLflow to support lightweight, local experiment tracking without requiring a server or cloud storage.

More features and documentation will be added in upcoming releases.